aztec-nr - noir_aztec::note::note_emission

Struct NoteEmission

pub struct NoteEmission<Note> {
    pub note: Note,
    pub storage_slot: Field,
    pub note_hash_counter: u32,
}

A note emission struct containing the information required for emitting a note. The exact emit logic is passed in by the application code

Fields

note: Note
storage_slot: Field
note_hash_counter: u32

Implementations

impl<Note> NoteEmission<Note>

pub fn new(note: Note, storage_slot: Field, note_hash_counter: u32) -> Self pub fn emit<Env>(self, _emit: fn[Env](Self)) pub fn discard(_self: Self)